@@ -24,17 +24,19 @@ def register():
         Account,
         AccountDeferral,
         OpenChartAccountStart,
-        PrintGeneralLedgerStart,
-        PrintTrialBalanceStart,
-        OpenBalanceSheetStart,
-        OpenIncomeStatementStart,
+        GeneralLedgerAccount,
+        GeneralLedgerAccountContext,
+        GeneralLedgerLine,
+        GeneralLedgerLineContext,
+        BalanceSheetContext,
+        IncomeStatementContext,
         CreateChartStart,
         CreateChartAccount,
         CreateChartProperties,
         UpdateChartStart,
         UpdateChartSucceed,
-        OpenThirdPartyBalanceStart,
-        OpenAgedBalanceStart,
+        AgedBalanceContext,
+        AgedBalance,
         Configuration,
         Period,
         JournalType,
@@ -45,6 +47,7 @@ def register():
         JournalPeriod,
         Move,
         Reconciliation,
+        ConfigurationTaxRounding,
         Line,
         OpenJournalAsk,
         ReconcileLinesWriteOff,
@@ -81,14 +84,8 @@ def register():
         BalanceNonDeferral,
         CloseFiscalYear,
         OpenChartAccount,
-        PrintGeneralLedger,
-        PrintTrialBalance,
-        OpenBalanceSheet,
-        OpenIncomeStatement,
         CreateChart,
         UpdateChart,
-        OpenThirdPartyBalance,
-        OpenAgedBalance,
         ClosePeriod,
         ReOpenPeriod,
         OpenJournalCash,
@@ -108,7 +105,6 @@ def register():
     Pool.register(
         GeneralLedger,
         TrialBalance,
-        ThirdPartyBalance,
-        AgedBalance,
+        AgedBalanceReport,
         GeneralJournal,
         module='account', type_='report')
