@@ -77,8 +77,7 @@ class JournalViewColumn(ModelSQL, ModelView):
     @classmethod
     def __register__(cls, module_name):
         TableHandler = backend.get('TableHandler')
-        cursor = Transaction().cursor
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
 
         super(JournalViewColumn, cls).__register__(module_name)
 
@@ -155,8 +154,8 @@ class Journal(ModelSQL, ModelView):
     def __register__(cls, module_name):
         TableHandler = backend.get('TableHandler')
         super(Journal, cls).__register__(module_name)
-        cursor = Transaction().cursor
-        table = TableHandler(cursor, cls, module_name)
+        cursor = Transaction().connection.cursor()
+        table = TableHandler(cls, module_name)
 
         # Migration from 1.0 sequence Many2One change into Property
         if table.column_exist('sequence'):
@@ -216,7 +215,7 @@ class Journal(ModelSQL, ModelView):
         MoveLine = pool.get('account.move.line')
         Move = pool.get('account.move')
         context = Transaction().context
-        cursor = Transaction().cursor
+        cursor = Transaction().connection.cursor()
 
         result = {}
         ids = [j.id for j in journals]
